=begin
(c) TIG 2011
All Rights Reserved.
THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED 
WARRANTIES,INCLUDING,WITHOUT LIMITATION,THE IMPLIED WARRANTIES OF 
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
###
Script:
TextureSwapper.rb
###
Swaps Textures between two standard folders.
###
Usage:
Type in the Ruby Console...
  TextureSwapper.out
OR use CADfather's toolbar 'TextureSwapper' item... still use Console to 
see what's happened...
All of the model's materials' textures image-files are exported into a 
folder with the model called 'ModelName_TexturesOUT', it's made if it 
doesn't exist.  It returns a message in the Console, including an array 
of the exported textures' image-files' names.
You can then copy that folder as 'ModelName_TexturesIN' and edit the 
texture image-files as desired - e.g. reducing their resolution or other 
adjustments to them...  Remove or do not alter textures that are to be 
left alone...
###
Next type in the Ruby Console...
  TextureSwapper.in
OR use CADfather's toolbar 'TextureSwapper' item... still use Console to 
see what's happened...
All of the model's materials' textures are updated using the image-files 
found in 'ModelName_TexturesIN'.  It returns a message in the Console, 
including an array of the imported textures' image-files' names.
The replacement textures use the previous texture size, so for example 
if you half the resolution of an image that is then imported it will 
still appears the same size in the model, because the original w/h are 
preserved.
The 'TextureSwapper.in' action is one step undoable - useful if you find 
that you don't like the results !
###
Donations: by PayPal.com to info @ revitrev.org
###
Version:
1.0 20111112 First issue.
1.1 20111112 Toolbar version created by CADfather, TIG tweaked.
1.2 20140720 Edited by Karel
###
=end
require 'sketchup.rb'
###
module TextureSwapper
###
    if not file_loaded?(File.basename(__FILE__))
      tts = UI::Toolbar.new("Textures")
      cmd1 = UI::Command.new("Export textures"){self.out}
      cmd1.small_icon = 'TIGtools/tswapout_16.png'
      cmd1.large_icon = 'TIGtools/tswapout_24.png'
      cmd1.tooltip = "Save textures into the folder"
      cmd1.status_bar_text="All mapped textures will be exported into the folder where is your Sketchup model."
      tts.add_item(cmd1)
      cmd2 = UI::Command.new("Import textures"){self.in}
      cmd2.small_icon = 'TIGtools/tswapin_16.png'
      cmd2.large_icon = 'TIGtools/tswapin_24.png'
      cmd2.tooltip = "Update all Textures"
      cmd2.status_bar_text="Will reload all textures from the folder and update them on your model."
      tts.add_item(cmd2)
    end
    file_loaded(File.basename(__FILE__))
###
    def self.out()
      adresar="Textures"
      model=Sketchup.active_model
      path=model.path
      if not path or path==""
        name="Untitled"
        output=File.join(Dir.pwd,adresar).tr("\\","/")
      else
        name=model.title
        output=File.join(File.dirname(path),adresar).tr("\\","/")
      end
      Dir.mkdir(output) unless File.exist?(output)
      ###
      group=model.entities.add_group
      tw = Sketchup.create_texture_writer
      count=0
      names=[]
      model.materials.each{|m|
        if m.texture
          names << File.basename(m.texture.filename)
          group.material= m
          tw.load(group, true)
          count=count+1
        end
      }
      tw.write_all(output, false)
      group.erase! if group.valid?
      ###
      puts "Saved "+count.to_s+" textures into the folder:\n"+output
      return names.sort
      ###
    end
     
    def self.in()
      adresar="Textures"
      model=Sketchup.active_model
      path=model.path
      if not path or path==""
        name="Untitled"
        input=File.join(Dir.pwd,adresar).tr("\\","/")
      else
        name=model.title
        input=File.join(File.dirname(path),adresar).tr("\\","/")
      end
      if not File.exist?(input)
        UI.messagebox("Cannot load!\nFolder is missing. Your textures must be placed in the folder:\n"+input)
        return nil
      end
      textures=[]
      Dir.entries(input).each{|f|
        next if f=='.' or f=='..'
        textures << File.join(input, f).tr("\\","/")
      }
      textures.sort!
      mats=model.materials
      count=0
      used=[]
      model.start_operation("TextureSwapper.in")
      textures.each{|t|
        mats.each{|m|
          next unless m.texture
          if File.basename(m.texture.filename)==File.basename(t)
            w=m.texture.width
            h=m.texture.height
            m.texture=t
            m.texture.size=[w,h]
            used << File.basename(t)
          end
        }
        count+=1
      }
      model.commit_operation
      puts +count.to_s+" textures updated!"
      return used.sort
      ###
    end
  UI.menu('Plugins').add_item('Aktualizovat textury'){TextureSwapper.in()} unless file_loaded?(__FILE__)
    file_loaded(__FILE__)
end
###


















